@@ -103,7 +103,7 @@ def qubits(clArgs=None):
     pathToSpectralDatabase = clArgs["<pathToSpectralDatabase>"]
 
     pathToOutputDirectory = os.path.abspath(pathToOutputDirectory)+"/"
-    pathToSettingsFile = os.path.abspath(pathToSettingsFile)+"/"
+    pathToSettingsFile = os.path.abspath(pathToSettingsFile)
     pathToSpectralDatabase = os.path.abspath(pathToSpectralDatabase)+"/"
 
     ## IMPORT THE SIMULATION SETTINGS
